@@ -23,8 +23,38 @@
 
 import gtk
 from hamster import storage
+import pango
 from pango import ELLIPSIZE_END
+
 import datetime as dt
+import locale
+
+# it seems that python or something has bug of sorts, that breaks stuff for
+# japanese locale, so we have this locale from and to ut8 magic in some places
+# see bug 562298
+def locale_from_utf8(utf8_str):
+    try:
+        retval = unicode (utf8_str, "utf-8").encode(locale.getpreferredencoding())
+    except:
+        retval = utf8_str
+    return retval
+
+def locale_to_utf8(locale_str):
+    try:
+        retval = unicode (locale_str, locale.getpreferredencoding()).encode("utf-8")
+    except:
+        retval = locale_str
+    return retval
+
+class CategoryCell(gtk.CellRendererText):
+    def __init__(self):
+        gtk.CellRendererText.__init__(self)        
+        self.set_property('alignment', pango.ALIGN_RIGHT)
+        
+        insensitive_color = gtk.Label().style.fg[gtk.STATE_INSENSITIVE]
+        self.set_property('foreground-gdk', insensitive_color)
+        self.set_property('scale', pango.SCALE_SMALL)
+        self.set_property('yalign', 0.0)
 
 class ExpanderColumn(gtk.TreeViewColumn):
     def __init__(self, label, text):
@@ -54,6 +84,37 @@ def format_duration(minutes):
             
     return formatted_duration
 
+def dateDict(date, prefix):
+    """converts date into dictionary, having prefix for all the keys"""
+    res = {}
+    
+    res[prefix+"a"] = date.strftime("%a")
+    res[prefix+"A"] = date.strftime("%A")
+    res[prefix+"b"] = date.strftime("%b")
+    res[prefix+"B"] = date.strftime("%B")
+    res[prefix+"c"] = date.strftime("%c")
+    res[prefix+"d"] = date.strftime("%d")
+    res[prefix+"H"] = date.strftime("%H")
+    res[prefix+"I"] = date.strftime("%I")
+    res[prefix+"j"] = date.strftime("%j")
+    res[prefix+"m"] = date.strftime("%m")
+    res[prefix+"M"] = date.strftime("%M")
+    res[prefix+"p"] = date.strftime("%p")
+    res[prefix+"S"] = date.strftime("%S")
+    res[prefix+"U"] = date.strftime("%U")
+    res[prefix+"w"] = date.strftime("%w")
+    res[prefix+"W"] = date.strftime("%W")
+    res[prefix+"x"] = date.strftime("%x")
+    res[prefix+"X"] = date.strftime("%X")
+    res[prefix+"y"] = date.strftime("%y")
+    res[prefix+"Y"] = date.strftime("%Y")
+    res[prefix+"Z"] = date.strftime("%Z")
+    
+    for i, value in res.items():
+        res[i] = locale_to_utf8(value)
+
+    return res
+
 class DayStore(object):
     """A day view contains a treeview for facts of the day and another
        one for totals. It creates those widgets on init, use
@@ -62,12 +123,9 @@ class DayStore(object):
     def __init__(self, date = None):
         date = date or dt.date.today()
         
-        # ID, Time, Name, Duration, Date
-        self.fact_store = gtk.ListStore(int, str, str, str, str)
+        # ID, Time, Name, Duration, Date, Description
+        self.fact_store = gtk.ListStore(int, str, str, str, str, str)
         
-        # Dummy ID to distinct between fact_store, Name, Duration
-        self.total_store = gtk.ListStore(int, str, str)
-
         self.facts = storage.get_facts(date)
         self.totals = {}
         
@@ -81,24 +139,19 @@ class DayStore(object):
                 delta = dt.datetime.now() - fact["start_time"]
                 duration = 24 * delta.days + delta.seconds / 60
             
-            fact_name = fact['name']
+            fact_category = fact['category']
             
-            if fact_name not in self.totals:
-                self.totals[fact_name] = 0
+            if fact_category not in self.totals:
+                self.totals[fact_category] = 0
 
             if duration:
-                self.totals[fact_name] += duration
+                self.totals[fact_category] += duration
 
             current_duration = format_duration(duration)
 
             self.fact_store.append([fact['id'], fact['name'], 
                                     fact["start_time"].strftime("%H:%M"), 
                                     current_duration,
-                                    fact["start_time"].strftime("%Y%m%d")])
-
-        # now we are good to append totals!
-        # no sorting - chronological is intuitive
-        for total in self.totals:
-            if (self.totals[total]) > 0: # TODO - check if this zero check is still necessary (it was 6min check before) 
-                self.total_store.append([-1, format_duration(self.totals[total]), total])
+                                    fact["start_time"].strftime("%Y%m%d"),
+                                    fact["description"]])
 
